summaryrefslogtreecommitdiffstats
path: root/js/app
diff options
context:
space:
mode:
authorBernhard Posselt <dev@bernhard-posselt.com>2016-07-23 22:04:59 +0200
committerBernhard Posselt <dev@bernhard-posselt.com>2016-07-23 22:04:59 +0200
commite336636166be51b2c6a53fb9a2ff837916fbb3cd (patch)
tree5e41ea38657a02d4ecc630f0fff3be32fb276f31 /js/app
parent38e657a5d5791919937ca8e0deb2460aaa103883 (diff)
some final renaming fixes
Diffstat (limited to 'js/app')
-rw-r--r--js/app/Config.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/js/app/Config.js b/js/app/Config.js
index 8300258ef..4ccbf8cba 100644
--- a/js/app/Config.js
+++ b/js/app/Config.js
@@ -29,7 +29,7 @@ app.config(function ($routeProvider, $provide, $httpProvider) {
$provide.constant('MARK_READ_TIMEOUT', 0.5);
$provide.constant('SCROLL_TIMEOUT', 0.1);
// make sure that the CSRF header is only sent to the ownCloud domain
$provide.factory('CSRFInterceptor', function ($q, BASE_URL, $window) {
return {
request: function (config) {
@@ -53,8 +53,8 @@ app.config(function ($routeProvider, $provide, $httpProvider) {
500: t('news', 'Internal server error! Please check your ' +
'data/owncloud.log file for additional ' +
'information!'),
- 503: t('news', 'Request failed, ownCloud is in currently ' +
- 'in maintenance mode!'),
+ 503: t('news', 'Request failed, Nextcloud is in currently ' +
+ 'in maintenance mode!')
};
$provide.factory('ConnectionErrorInterceptor', function ($q, $timeout) {
var timer;
@@ -29,7 +29,7 @@ app.config(function ($routeProvider, $provide, $httpProvider) {
$provide.constant('MARK_READ_TIMEOUT', 0.5);
$provide.constant('SCROLL_TIMEOUT', 0.1);
- // make sure that the CSRF header is only sent to the ownCloud domain
+ // make sure that the CSRF header is only sent to the Nextcloud domain
$provide.factory('CSRFInterceptor', function ($q, BASE_URL, $window) {
return {